#ifndef _EFL_UI_VIEW_LIST_MODEL_EO_H_
#define _EFL_UI_VIEW_LIST_MODEL_EO_H_

#ifndef _EFL_UI_VIEW_LIST_MODEL_EO_CLASS_TYPE
#define _EFL_UI_VIEW_LIST_MODEL_EO_CLASS_TYPE

typedef Eo Efl_Ui_View_List_Model;

#endif

#ifndef _EFL_UI_VIEW_LIST_MODEL_EO_TYPES
#define _EFL_UI_VIEW_LIST_MODEL_EO_TYPES


#endif
#define EFL_UI_VIEW_LIST_MODEL_INTERFACE efl_ui_view_list_model_interface_get()

EWAPI const Efl_Class *efl_ui_view_list_model_interface_get(void);

EOAPI void efl_ui_view_list_model_load_range_set(Eo *obj, int first, int count);

EOAPI Efl_Ui_View_List_LayoutItem *efl_ui_view_list_model_realize(Eo *obj, Efl_Ui_View_List_LayoutItem *item);

EOAPI void efl_ui_view_list_model_unrealize(Eo *obj, Efl_Ui_View_List_LayoutItem *item);

EOAPI int efl_ui_view_list_model_size_get(const Eo *obj);

/**
 * @brief Minimal content size.
 *
 * @param[in] obj The object.
 * @param[in] min
 *
 * @ingroup Efl_Ui_View_List_Model
 */
EOAPI void efl_ui_view_list_model_min_size_set(Eo *obj, Eina_Size2D min);

/** Minimal content size.
 *
 * @ingroup Efl_Ui_View_List_Model
 */
EOAPI Eina_Size2D efl_ui_view_list_model_min_size_get(const Eo *obj);

#endif
