#ifndef EFL_UI_VIEW_LIST_MODEL_IMPL_HH
#define EFL_UI_VIEW_LIST_MODEL_IMPL_HH

#include "efl_ui_view_list_model.eo.hh"

namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<void>::type View_List_Model::load_range_set( ::efl::eolian::in_traits<int>::type first,  ::efl::eolian::in_traits<int>::type count) const
{
    ::efl_ui_view_list_model_load_range_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(first)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(count));
}
inline ::efl::eolian::return_traits<int>::type View_List_Model::model_size_get() const
{
   int __return_value =  ::efl_ui_view_list_model_size_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<Eina_Size2D>::type View_List_Model::min_size_get() const
{
   Eina_Size2D __return_value =  ::efl_ui_view_list_model_min_size_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Size2D>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View_List_Model::min_size_set( ::efl::eolian::in_traits<Eina_Size2D>::type min) const
{
    ::efl_ui_view_list_model_min_size_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Size2D,  ::efl::eolian::in_traits<Eina_Size2D>::type>(min));
}
inline ::efl::eolian::return_traits<Efl_Ui_View_List_LayoutItem&>::type View_List_Model::realize( ::efl::eolian::in_traits<Efl_Ui_View_List_LayoutItem const&>::type item) const
{
   Efl_Ui_View_List_LayoutItem * __return_value =  ::efl_ui_view_list_model_realize(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Ui_View_List_LayoutItem *,  ::efl::eolian::in_traits<Efl_Ui_View_List_LayoutItem const&>::type>(item));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Ui_View_List_LayoutItem&>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View_List_Model::unrealize( ::efl::eolian::in_traits<Efl_Ui_View_List_LayoutItem const&>::type item) const
{
    ::efl_ui_view_list_model_unrealize(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Ui_View_List_LayoutItem *,  ::efl::eolian::in_traits<Efl_Ui_View_List_LayoutItem const&>::type>(item));
}
} } 
namespace eo_cxx {
namespace efl { namespace ui { 
inline ::efl::eolian::return_traits<void>::type View_List_Model::load_range_set( ::efl::eolian::in_traits<int>::type first,  ::efl::eolian::in_traits<int>::type count) const
{
    ::efl_ui_view_list_model_load_range_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(first)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(count));
}
inline ::efl::eolian::return_traits<int>::type View_List_Model::model_size_get() const
{
   int __return_value =  ::efl_ui_view_list_model_size_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<Eina_Size2D>::type View_List_Model::min_size_get() const
{
   Eina_Size2D __return_value =  ::efl_ui_view_list_model_min_size_get(_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Eina_Size2D>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View_List_Model::min_size_set( ::efl::eolian::in_traits<Eina_Size2D>::type min) const
{
    ::efl_ui_view_list_model_min_size_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Size2D,  ::efl::eolian::in_traits<Eina_Size2D>::type>(min));
}
inline ::efl::eolian::return_traits<Efl_Ui_View_List_LayoutItem&>::type View_List_Model::realize( ::efl::eolian::in_traits<Efl_Ui_View_List_LayoutItem const&>::type item) const
{
   Efl_Ui_View_List_LayoutItem * __return_value =  ::efl_ui_view_list_model_realize(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Ui_View_List_LayoutItem *,  ::efl::eolian::in_traits<Efl_Ui_View_List_LayoutItem const&>::type>(item));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Ui_View_List_LayoutItem&>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View_List_Model::unrealize( ::efl::eolian::in_traits<Efl_Ui_View_List_LayoutItem const&>::type item) const
{
    ::efl_ui_view_list_model_unrealize(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Efl_Ui_View_List_LayoutItem *,  ::efl::eolian::in_traits<Efl_Ui_View_List_LayoutItem const&>::type>(item));
}
inline efl::ui::View_List_Model::operator ::efl::ui::View_List_Model() const { return *static_cast< ::efl::ui::View_List_Model const*>(static_cast<void const*>(this)); }
inline efl::ui::View_List_Model::operator ::efl::ui::View_List_Model&() { return *static_cast< ::efl::ui::View_List_Model*>(static_cast<void*>(this)); }
inline efl::ui::View_List_Model::operator ::efl::ui::View_List_Model const&() const { return *static_cast< ::efl::ui::View_List_Model const*>(static_cast<void const*>(this)); }
} } }
#endif
